## START: Set by rpmautospec
## (rpmautospec version 0.2.5)
%define autorelease(e:s:pb:) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{?dist}
## END: Set by rpmautospec

# Sphinx-generated HTML documentation is not suitable for packaging; see
# https://bugzilla.redhat.com/show_bug.cgi?id=2006555 for discussion.
#
# We can generate PDF documentation as a substitute.
%bcond_without doc_pdf

# As of 2021-10-20, PySide6 (https://pypi.org/project/PySide6/) is not yet
# packaged in Fedora. When it is, we should use it.
%bcond_with qt6

# The GitHub tarball has documentation and examples; the PyPI one does not.
%global forgeurl https://github.com/mozman/ezdxf

Name:           python-ezdxf
Version:        0.17.2
%forgemeta
Release:        %autorelease
Summary:        Create/manipulate DXF drawings

License:        MIT
URL:            https://ezdxf.mozman.at/
Source0:        %{forgesource}

# Man pages written for Fedora in groff_man(7) format based on --help output
# and docs/ content.
Source10:       ezdxf.1
Source11:       ezdxf-audit.1
Source12:       ezdxf-browse.1
Source13:       ezdxf-config.1
Source14:       ezdxf-draw.1
Source15:       ezdxf-info.1
Source16:       ezdxf-pp.1
Source17:       ezdxf-strip.1
Source18:       ezdxf-view.1

BuildRequires:  python3-devel
BuildRequires:  gcc-c++

BuildRequires:  dos2unix

# Standard styles use OpenSans and Liberation fonts; see
# src/ezdxf/tools/standards.py
BuildRequires:  font(opensans)
BuildRequires:  font(opensansextrabold)
BuildRequires:  font(opensanslight)
BuildRequires:  font(opensanssemibold)
BuildRequires:  font(liberationmono)
BuildRequires:  font(liberationsans)
BuildRequires:  font(liberationsansnarrow)
BuildRequires:  font(liberationserif)
# This is used in tests/test_08_addons/test_814_text2path.py. (The test is
# simply skipped if the font is not present.)
BuildRequires:  font(notosanssc)

%if %{with doc_pdf}
BuildRequires:  make
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3-sphinx-latex
BuildRequires:  latexmk
BuildRequires:  /usr/bin/xindy
BuildRequires:  tex-xetex-bin
BuildRequires:  inkscape
%endif

%global common_description %{expand:
A Python package to create and modify DXF drawings, independent of the DXF
version. You can open/save every DXF file without losing any content (except
comments). Unknown tags in the DXF file will be ignored but preserved for
saving. With this behavior it is possible to open also DXF drawings that
contains data from 3rd party applications.}

%description %{common_description}


%package -n     python3-ezdxf
Summary:        %{summary}

Requires:       font(opensans)
Requires:       font(opensansextrabold)
Requires:       font(opensanslight)
Requires:       font(opensanssemibold)
Requires:       font(liberationmono)
Requires:       font(liberationsans)
Requires:       font(liberationsansnarrow)
Requires:       font(liberationserif)

%description -n python3-ezdxf %{common_description}


%pyproject_extras_subpkg -n python3-ezdxf %{?with_qt6:all,draw},all5,draw5


%package        doc
Summary:        Documentation for ezdxf

BuildArch:      noarch

%description    doc %{common_description}


%prep
%forgeautosetup
# Note that C++ sources in the GitHub tarball are *not* Cython-generated, and
# we must not remove them.

# Remove bundled fonts; these would not be installed anyway.
rm -rvf fonts/

# Since pdflatex cannot handle Unicode inputs in general:
echo "latex_engine = 'xelatex'" >> docs/source/conf.py
rm docs/graphics/dimtad-dimjust.pdf

# Fix files with CRNL newlines and, in some cases, UTF-16LE encoding:
dos2unix docs/notes/dxf-group-code-reference.txt \
    examples/copydxf.py \
    examples_dxf/text.dxf \
    examples_dxf/text_negative_extrusion.dxf

# qtviewer.py is not exectuable and is not script-like (no main routine or
# useful side effects), so it does not need a shebang
sed -r -i '1{/^#!/d}' src/ezdxf/addons/drawing/qtviewer.py

# A couple of examples are installed as executables, with shebangs that need to
# be corrected.
%py3_shebang_fix examples

# Copy in downstream man pages
mkdir man
cp -p '%{SOURCE10}' '%{SOURCE11}' '%{SOURCE12}' '%{SOURCE13}' '%{SOURCE14}' \
  '%{SOURCE15}' '%{SOURCE16}' '%{SOURCE17}' '%{SOURCE18}' man/


%generate_buildrequires
# Note extra “all” is “draw”+“dev”+“test”, and “all5” is “draw5”+“dev”+“test”.
%pyproject_buildrequires -x all%{?!with_qt6:5}


%build
%pyproject_wheel

%if %{with doc_pdf}
# Cannot use SVG images when building PDF documentation; convert to PDFs
find docs -type f -name '*.svg' |
  while read -r fn
  do
    inkscape -C -o "$(dirname "${fn}")/$(basename "${fn}" .svg).pdf" "${fn}"
  done
find docs/source -type f -exec \
    gawk '/\.svg/ { print FILENAME; nextfile }' '{}' '+' |
  xargs -r -t sed -r -i 's/\.svg/\.pdf/g'

PYTHONPATH="%{pyproject_build_lib}" %make_build -C docs latex \
    SPHINXOPTS='%{?_smp_mflags}' SPHINXBUILD='sphinx-build-3'
%make_build -C docs/build/latex LATEXMKOPTS='-quiet'
%endif


%install
%pyproject_install
%pyproject_save_files ezdxf

install -t '%{buildroot}%{_mandir}/man1' -D -p -m 0644 man/*.1


%check
# No need to set EZDXF_TEST_FILES because the files in question are not
# available (and are presumably not freely distributable). This is fine; it
# just means a few tests are automatically skipped.

# See tox-extras.ini:
%pytest -k "${k-}" tests integration_tests

# Since the user can disable the C extensions, test the pure-Python
# implementations too:
EZDXF_DISABLE_C_EXT=1 %pytest -k "${k-}" tests integration_tests

%files -n python3-ezdxf -f %{pyproject_files}
# pyproject-rpm-macros handles the LICENSE file; verify with “rpm -qL -p …”
%doc README.md

%{_bindir}/ezdxf
%{_mandir}/man1/ezdxf*.1*


%files doc
%license LICENSE

%doc NEWS*.md
%doc README.md
%doc TODO.md

%doc autolisp
%doc examples
%doc examples_dxf
%doc exploration
%doc docs/notes

%if %{with doc_pdf}
%doc docs/build/latex/ezdxf.pdf
%endif


%changelog
* Thu Mar 03 2022 Benjamin A. Beasley <code@musicinmybrain.net> 0.17.2-1
- Initial package (close RHBZ#2040816)
